AdminUserListResponse class abstract

AdminUserListResponse

Properties:

Annotations
  • @BuiltValue.new()

Constructors

AdminUserListResponse([void updates(AdminUserListResponseBuilder b)])
factory

Properties

data → BuiltList<AdminUser>
no setter
hashCode int
The hash code for this object.
no setterinherited
meta PaginationMeta
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(AdminUserListResponseBuilder)) AdminUserListResponse
Rebuilds the instance.
inherited
toBuilder() AdminUserListResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<AdminUserListResponse>
no setter